==> vala-0.1.2.tar.gz: vala-0.1.2/ccode/valaccodeconstant.c <==
/* valaccodeconstant.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaccodeconstant.h"
#include <ccode/valaccodeconstant.h>

struct _ValaCCodeConstantPrivate {
	char* _name;
};
#define VALA_CCODE_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CONSTANT, ValaCCodeConstantPrivate))
enum  {
	VALA_CCODE_CONSTANT_DUMMY_PROPERTY,
	VALA_CCODE_CONSTANT_NAME
};
static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_constant_parent_class = NULL;
static void vala_ccode_constant_dispose (GObject * obj);


ValaCCodeConstant* vala_ccode_constant_new (const char* _name)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeConstant * self;
	g_return_val_if_fail (_name != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_CONSTANT, __params_it - __params, __params);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeConstant * self;
	self = ((ValaCCodeConstant*) base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_string (writer, vala_ccode_constant_get_name (self));
}


char* vala_ccode_constant_get_name (ValaCCodeConstant* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_CONSTANT (self), NULL);
	return self->priv->_name;
}


void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value)
{
	char* __temp1;
	g_return_if_fail (VALA_IS_CCODE_CONSTANT (self));
	__temp1 = NULL;
	self->priv->_name = (__temp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), __temp1);
}


static void vala_ccode_constant_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeConstant * self;
	self = VALA_CCODE_CONSTANT (object);
	switch (property_id) {
		case VALA_CCODE_CONSTANT_NAME:
		g_value_set_string (value, vala_ccode_constant_get_name (self));
		break;
	}
}


static void vala_ccode_constant_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeConstant * self;
	self = VALA_CCODE_CONSTANT (object);
	switch (property_id) {
		case VALA_CCODE_CONSTANT_NAME:
		vala_ccode_constant_set_name (self, g_value_get_string (value));
		break;
	}
}


static void vala_ccode_constant_class_init (ValaCCodeConstantClass * klass)
{
	vala_ccode_constant_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeConstantPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_constant_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_constant_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_constant_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_constant_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CONSTANT_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_constant_init (ValaCCodeConstant * self)
{
	self->priv = VALA_CCODE_CONSTANT_GET_PRIVATE (self);
}


static void vala_ccode_constant_dispose (GObject * obj)
{
	ValaCCodeConstant * self;
	ValaCCodeConstantClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_CONSTANT (obj);
	(self->priv->_name = (g_free (self->priv->_name), NULL));
	klass = VALA_CCODE_CONSTANT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_CONSTANT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_constant_get_type (void)
{
	static GType vala_ccode_constant_type_id = 0;
	if (G_UNLIKELY (vala_ccode_constant_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConstant), 0, (GInstanceInitFunc) vala_ccode_constant_init };
		vala_ccode_constant_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeConstant", &g_define_type_info, 0);
	}
	return vala_ccode_constant_type_id;
}

==> vala-0.1.3.tar.gz: vala-0.1.3/ccode/valaccodeconstant.c <==
/* valaccodeconstant.vala
 *
 * Copyright (C) 2006  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include "valaccodeconstant.h"
#include <ccode/valaccodeconstant.h>

struct _ValaCCodeConstantPrivate {
	char* _name;
};
#define VALA_CCODE_CONSTANT_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_CONSTANT, ValaCCodeConstantPrivate))
enum  {
	VALA_CCODE_CONSTANT_DUMMY_PROPERTY,
	VALA_CCODE_CONSTANT_NAME
};
static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer);
static gpointer vala_ccode_constant_parent_class = NULL;
static void vala_ccode_constant_dispose (GObject * obj);


ValaCCodeConstant* vala_ccode_constant_new (const char* _name)
{
	GParameter * __params;
	GParameter * __params_it;
	ValaCCodeConstant * self;
	g_return_val_if_fail (_name != NULL, NULL);
	__params = g_new0 (GParameter, 1);
	__params_it = __params;
	(__params_it->name = "name", g_value_init (&__params_it->value, G_TYPE_STRING), g_value_set_string (&__params_it->value, _name), __params_it++);
	self = g_object_newv (VALA_TYPE_CCODE_CONSTANT, __params_it - __params, __params);
	while (__params_it > __params) {
		--__params_it;
		g_value_unset (&__params_it->value);
	}
	g_free (__params);
	return self;
}


static void vala_ccode_constant_real_write (ValaCCodeNode* base, ValaCCodeWriter* writer)
{
	ValaCCodeConstant * self;
	self = ((ValaCCodeConstant*) base);
	g_return_if_fail (VALA_IS_CCODE_WRITER (writer));
	vala_ccode_writer_write_string (writer, vala_ccode_constant_get_name (self));
}


char* vala_ccode_constant_get_name (ValaCCodeConstant* self)
{
	g_return_val_if_fail (VALA_IS_CCODE_CONSTANT (self), NULL);
	return self->priv->_name;
}


void vala_ccode_constant_set_name (ValaCCodeConstant* self, const char* value)
{
	char* _tmp1;
	g_return_if_fail (VALA_IS_CCODE_CONSTANT (self));
	_tmp1 = NULL;
	self->priv->_name = (_tmp1 = g_strdup (value), (self->priv->_name = (g_free (self->priv->_name), NULL)), _tmp1);
}


static void vala_ccode_constant_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
{
	ValaCCodeConstant * self;
	self = VALA_CCODE_CONSTANT (object);
	switch (property_id) {
		case VALA_CCODE_CONSTANT_NAME:
		g_value_set_string (value, vala_ccode_constant_get_name (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_ccode_constant_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
{
	ValaCCodeConstant * self;
	self = VALA_CCODE_CONSTANT (object);
	switch (property_id) {
		case VALA_CCODE_CONSTANT_NAME:
		vala_ccode_constant_set_name (self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_ccode_constant_class_init (ValaCCodeConstantClass * klass)
{
	vala_ccode_constant_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaCCodeConstantPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_ccode_constant_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_ccode_constant_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_ccode_constant_dispose;
	VALA_CCODE_NODE_CLASS (klass)->write = vala_ccode_constant_real_write;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_CCODE_CONSTANT_NAME, g_param_spec_string ("name", "foo", "bar", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
}


static void vala_ccode_constant_init (ValaCCodeConstant * self)
{
	self->priv = VALA_CCODE_CONSTANT_GET_PRIVATE (self);
}


static void vala_ccode_constant_dispose (GObject * obj)
{
	ValaCCodeConstant * self;
	ValaCCodeConstantClass * klass;
	GObjectClass * parent_class;
	self = VALA_CCODE_CONSTANT (obj);
	(self->priv->_name = (g_free (self->priv->_name), NULL));
	klass = VALA_CCODE_CONSTANT_CLASS (g_type_class_peek (VALA_TYPE_CCODE_CONSTANT));
	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
	parent_class->dispose (obj);
}


GType vala_ccode_constant_get_type (void)
{
	static GType vala_ccode_constant_type_id = 0;
	if (G_UNLIKELY (vala_ccode_constant_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaCCodeConstantClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_ccode_constant_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaCCodeConstant), 0, (GInstanceInitFunc) vala_ccode_constant_init };
		vala_ccode_constant_type_id = g_type_register_static (VALA_TYPE_CCODE_EXPRESSION, "ValaCCodeConstant", &g_define_type_info, 0);
	}
	return vala_ccode_constant_type_id;
}
